Title: creative_frameworks
Description: Various LLMS from @guillaumedescoteauxisabelle's research on the Creative Frameworks Extension
Issue URL: https://github.com/miadisabelle/mcpdoc/issues/2
issue_id: 2
